# Generated by Django 4.0.10 on 2023-06-16 13:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('authstats', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='reportdatathrough',
            name='checkbox_only',
            field=models.BooleanField(default=False),
        ),
    ]
