*{margin:0;padding:0}.flex{align-items:center;display:flex;height:80px}.child{margin-right:20px}.child-end{margin-left:auto}.fill-width{overflow:auto}.float-left{float:left}.flex-container{align-items:center;flex-wrap:wrap}.flex-container,.flex-container-pull-right{align-content:center;display:flex;flex-direction:row;justify-content:center}.flex-container-pull-right{align-items:flex-end}.flex-container-vert-fill{align-content:stretch;align-items:stretch;display:flex;flex-direction:column;flex-wrap:wrap;justify-content:center}.flex-child{margin:10px}.spinner-size{height:30px;margin:200px;width:30px}.char-portrait{margin:auto;position:relative}.corp-logo{left:0}.alli-logo,.corp-logo{bottom:0;margin:5px;position:absolute}.alli-logo{right:0}.flex-body{align-items:center}.table-div{height:250px;overflow-y:overlay;width:400px}.table-div::-webkit-scrollbar{background:transparent;width:3}.table-div::-webkit-scrollbar-thumb{background-clip:padding-box;background-color:#375a7f4b;border-left:15px solid transparent}table tbbody tr td{vertical-align:middle!important}.no-wrap{white-space:nowrap}@media only screen and (max-width:1600px){.info-hide{display:none}}@media only screen and (max-width:1400px){.association-hide{display:none}}.btn-group.special{display:flex}.special .btn{background-color:initial;border:1px solid #f0ad4e;color:inherit;flex:1 1}.no-grow{background:#f0ad4e!important;color:#fff;flex-grow:0!important}.lds-ripple{display:inline-block;height:80px;position:relative;width:80px}.lds-ripple div{-webkit-animation:lds-ripple 1s cubic-bezier(0,.2,.8,1) infinite;animation:lds-ripple 1s cubic-bezier(0,.2,.8,1) infinite;border:4px solid #888;border-radius:50%;opacity:1;position:absolute}.lds-ripple div:nth-child(2){-webkit-animation-delay:-.5s;animation-delay:-.5s}@-webkit-keyframes lds-ripple{0%{height:0;left:36px;opacity:1;top:36px;width:0}to{height:72px;left:0;opacity:0;top:0;width:72px}}@keyframes lds-ripple{0%{height:0;left:36px;opacity:1;top:36px;width:0}to{height:72px;left:0;opacity:0;top:0;width:72px}}.flex-label-container{align-content:stretch;align-items:stretch;display:flex;flex-direction:row;flex-wrap:nowrap;justify-content:flex-start}.flex-label{margin:2px}.flex-select{flex:1 1;margin:2px}.flex-select-size{width:300px}
/*# sourceMappingURL=main.ec2c1bf0.css.map*/