# Generated by Django 4.0.10 on 2023-06-24 10:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('authstats', '0007_reportdatathrough_allow_sort'),
    ]

    operations = [
        migrations.AlterField(
            model_name='reportdatathrough',
            name='long_descriptions',
            field=models.CharField(
                blank=True, default=None, help_text='Long description shown to the user on hover of column name.', max_length=500, null=True),
        ),
    ]
